@@ -29,20 +29,28 @@ from .types.cluster_service import Cluster
 from .types.cluster_service import ClusterAutoscaling
 from .types.cluster_service import ClusterUpdate
 from .types.cluster_service import CompleteIPRotationRequest
+from .types.cluster_service import ConfigConnectorConfig
 from .types.cluster_service import CreateClusterRequest
 from .types.cluster_service import CreateNodePoolRequest
 from .types.cluster_service import DailyMaintenanceWindow
 from .types.cluster_service import DatabaseEncryption
+from .types.cluster_service import DefaultSnatStatus
 from .types.cluster_service import DeleteClusterRequest
 from .types.cluster_service import DeleteNodePoolRequest
+from .types.cluster_service import DnsCacheConfig
 from .types.cluster_service import GetClusterRequest
+from .types.cluster_service import GetJSONWebKeysRequest
+from .types.cluster_service import GetJSONWebKeysResponse
 from .types.cluster_service import GetNodePoolRequest
+from .types.cluster_service import GetOpenIDConfigRequest
+from .types.cluster_service import GetOpenIDConfigResponse
 from .types.cluster_service import GetOperationRequest
 from .types.cluster_service import GetServerConfigRequest
 from .types.cluster_service import HorizontalPodAutoscaling
 from .types.cluster_service import HttpLoadBalancing
 from .types.cluster_service import IPAllocationPolicy
 from .types.cluster_service import IntraNodeVisibilityConfig
+from .types.cluster_service import Jwk
 from .types.cluster_service import KubernetesDashboard
 from .types.cluster_service import LegacyAbac
 from .types.cluster_service import ListClustersRequest
@@ -67,11 +75,16 @@ from .types.cluster_service import NodePool
 from .types.cluster_service import NodePoolAutoscaling
 from .types.cluster_service import NodeTaint
 from .types.cluster_service import Operation
+from .types.cluster_service import OperationProgress
 from .types.cluster_service import PrivateClusterConfig
+from .types.cluster_service import PrivateClusterMasterGlobalAccessConfig
 from .types.cluster_service import RecurringTimeWindow
+from .types.cluster_service import ReleaseChannel
+from .types.cluster_service import ReservationAffinity
 from .types.cluster_service import ResourceLimit
 from .types.cluster_service import ResourceUsageExportConfig
 from .types.cluster_service import RollbackNodePoolUpgradeRequest
+from .types.cluster_service import SandboxConfig
 from .types.cluster_service import ServerConfig
 from .types.cluster_service import SetAddonsConfigRequest
 from .types.cluster_service import SetLabelsRequest
@@ -86,6 +99,7 @@ from .types.cluster_service import SetNodePoolAutoscalingRequest
 from .types.cluster_service import SetNodePoolManagementRequest
 from .types.cluster_service import SetNodePoolSizeRequest
 from .types.cluster_service import ShieldedInstanceConfig
+from .types.cluster_service import ShieldedNodes
 from .types.cluster_service import StartIPRotationRequest
 from .types.cluster_service import StatusCondition
 from .types.cluster_service import TimeWindow
@@ -95,6 +109,8 @@ from .types.cluster_service import UpdateNodePoolRequest
 from .types.cluster_service import UsableSubnetwork
 from .types.cluster_service import UsableSubnetworkSecondaryRange
 from .types.cluster_service import VerticalPodAutoscaling
+from .types.cluster_service import WorkloadIdentityConfig
+from .types.cluster_service import WorkloadMetadataConfig
 
 
 __all__ = (
@@ -111,20 +127,28 @@ __all__ = (
     "ClusterAutoscaling",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "ConfigConnectorConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
     "DailyMaintenanceWindow",
     "DatabaseEncryption",
+    "DefaultSnatStatus",
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
+    "DnsCacheConfig",
     "GetClusterRequest",
+    "GetJSONWebKeysRequest",
+    "GetJSONWebKeysResponse",
     "GetNodePoolRequest",
+    "GetOpenIDConfigRequest",
+    "GetOpenIDConfigResponse",
     "GetOperationRequest",
     "GetServerConfigRequest",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
     "IPAllocationPolicy",
     "IntraNodeVisibilityConfig",
+    "Jwk",
     "KubernetesDashboard",
     "LegacyAbac",
     "ListClustersRequest",
@@ -149,11 +173,16 @@ __all__ = (
     "NodePoolAutoscaling",
     "NodeTaint",
     "Operation",
+    "OperationProgress",
     "PrivateClusterConfig",
+    "PrivateClusterMasterGlobalAccessConfig",
     "RecurringTimeWindow",
+    "ReleaseChannel",
+    "ReservationAffinity",
     "ResourceLimit",
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
+    "SandboxConfig",
     "ServerConfig",
     "SetAddonsConfigRequest",
     "SetLabelsRequest",
@@ -168,6 +197,7 @@ __all__ = (
     "SetNodePoolManagementRequest",
     "SetNodePoolSizeRequest",
     "ShieldedInstanceConfig",
+    "ShieldedNodes",
     "StartIPRotationRequest",
     "StatusCondition",
     "TimeWindow",
@@ -177,5 +207,7 @@ __all__ = (
     "UsableSubnetwork",
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
+    "WorkloadIdentityConfig",
+    "WorkloadMetadataConfig",
     "ClusterManagerClient",
 )
