@@ -220,6 +220,9 @@ class ClusterManagerTransport(abc.ABC):
                 default_timeout=20.0,
                 client_info=client_info,
             ),
+            self.get_json_web_keys: gapic_v1.method.wrap_method(
+                self.get_json_web_keys, default_timeout=None, client_info=client_info,
+            ),
             self.list_node_pools: gapic_v1.method.wrap_method(
                 self.list_node_pools,
                 default_retry=retries.Retry(
@@ -491,6 +494,18 @@ class ClusterManagerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_json_web_keys(
+        self,
+    ) -> typing.Callable[
+        [cluster_service.GetJSONWebKeysRequest],
+        typing.Union[
+            cluster_service.GetJSONWebKeysResponse,
+            typing.Awaitable[cluster_service.GetJSONWebKeysResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def list_node_pools(
         self,
