@@ -90,10 +90,10 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
                 for grpc channel. It is ignored if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
 
         Raises:
@@ -102,6 +102,8 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._ssl_channel_credentials = ssl_channel_credentials
+
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
             # provided.
@@ -109,6 +111,7 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
 
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
+            self._ssl_channel_credentials = None
         elif api_mtls_endpoint:
             warnings.warn(
                 "api_mtls_endpoint and client_cert_source are deprecated",
@@ -144,7 +147,12 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
                 ssl_credentials=ssl_credentials,
                 scopes=scopes or self.AUTH_SCOPES,
                 quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
+            self._ssl_channel_credentials = ssl_credentials
         else:
             host = host if ":" in host else host + ":443"
 
@@ -161,6 +169,10 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
                 ssl_credentials=ssl_channel_credentials,
                 scopes=scopes or self.AUTH_SCOPES,
                 quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
 
         self._stubs = {}  # type: Dict[str, Callable]
@@ -187,7 +199,7 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
     ) -> grpc.Channel:
         """Create and return a gRPC channel object.
         Args:
-            address (Optionsl[str]): The host for the channel to use.
+            address (Optional[str]): The host for the channel to use.
             credentials (Optional[~.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify this application to the service. If
@@ -222,12 +234,8 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Create the channel designed to connect to this service.
-
-        This property caches on the instance; repeated calls return
-        the same channel.
+        """Return the channel designed to connect to this service.
         """
-        # Return the channel from cache.
         return self._grpc_channel
 
     @property
@@ -493,7 +501,9 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
     ) -> Callable[[cluster_service.SetLocationsRequest], cluster_service.Operation]:
         r"""Return a callable for the set locations method over gRPC.
 
-        Sets the locations for a specific cluster.
+        Sets the locations for a specific cluster. Deprecated. Use
+        `projects.locations.clusters.update <https://cloud.google.com/kubernetes-engine/docs/reference/rest/v1/projects.locations.clusters/update>`__
+        instead.
 
         Returns:
             Callable[[~.SetLocationsRequest],
@@ -713,6 +723,37 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
             )
         return self._stubs["get_server_config"]
 
+    @property
+    def get_json_web_keys(
+        self,
+    ) -> Callable[
+        [cluster_service.GetJSONWebKeysRequest], cluster_service.GetJSONWebKeysResponse
+    ]:
+        r"""Return a callable for the get json web keys method over gRPC.
+
+        Gets the public component of the cluster signing keys
+        in JSON Web Key format.
+        This API is not yet intended for general use, and is not
+        available for all clusters.
+
+        Returns:
+            Callable[[~.GetJSONWebKeysRequest],
+                    ~.GetJSONWebKeysResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_json_web_keys" not in self._stubs:
+            self._stubs["get_json_web_keys"] = self.grpc_channel.unary_unary(
+                "/google.container.v1.ClusterManager/GetJSONWebKeys",
+                request_serializer=cluster_service.GetJSONWebKeysRequest.serialize,
+                response_deserializer=cluster_service.GetJSONWebKeysResponse.deserialize,
+            )
+        return self._stubs["get_json_web_keys"]
+
     @property
     def list_node_pools(
         self,
