@@ -147,6 +147,8 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._ssl_channel_credentials = ssl_channel_credentials
+
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
             # provided.
@@ -154,6 +156,7 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
 
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
+            self._ssl_channel_credentials = None
         elif api_mtls_endpoint:
             warnings.warn(
                 "api_mtls_endpoint and client_cert_source are deprecated",
@@ -189,7 +192,12 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
                 ssl_credentials=ssl_credentials,
                 scopes=scopes or self.AUTH_SCOPES,
                 quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
+            self._ssl_channel_credentials = ssl_credentials
         else:
             host = host if ":" in host else host + ":443"
 
@@ -206,6 +214,10 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
                 ssl_credentials=ssl_channel_credentials,
                 scopes=scopes or self.AUTH_SCOPES,
                 quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
 
         # Run the base constructor.
@@ -508,7 +520,9 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
     ]:
         r"""Return a callable for the set locations method over gRPC.
 
-        Sets the locations for a specific cluster.
+        Sets the locations for a specific cluster. Deprecated. Use
+        `projects.locations.clusters.update <https://cloud.google.com/kubernetes-engine/docs/reference/rest/v1/projects.locations.clusters/update>`__
+        instead.
 
         Returns:
             Callable[[~.SetLocationsRequest],
@@ -738,6 +752,38 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
             )
         return self._stubs["get_server_config"]
 
+    @property
+    def get_json_web_keys(
+        self,
+    ) -> Callable[
+        [cluster_service.GetJSONWebKeysRequest],
+        Awaitable[cluster_service.GetJSONWebKeysResponse],
+    ]:
+        r"""Return a callable for the get json web keys method over gRPC.
+
+        Gets the public component of the cluster signing keys
+        in JSON Web Key format.
+        This API is not yet intended for general use, and is not
+        available for all clusters.
+
+        Returns:
+            Callable[[~.GetJSONWebKeysRequest],
+                    Awaitable[~.GetJSONWebKeysResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_json_web_keys" not in self._stubs:
+            self._stubs["get_json_web_keys"] = self.grpc_channel.unary_unary(
+                "/google.container.v1.ClusterManager/GetJSONWebKeys",
+                request_serializer=cluster_service.GetJSONWebKeysRequest.serialize,
+                response_deserializer=cluster_service.GetJSONWebKeysResponse.deserialize,
+            )
+        return self._stubs["get_json_web_keys"]
+
     @property
     def list_node_pools(
         self,
