@@ -112,7 +112,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -125,7 +125,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -172,7 +172,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -185,7 +185,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -198,7 +198,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -214,7 +214,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -227,12 +227,15 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
             ),
+            self.get_json_web_keys: gapic_v1.method.wrap_method(
+                self.get_json_web_keys, default_timeout=None, client_info=client_info,
+            ),
             self.get_node_pool: gapic_v1.method.wrap_method(
                 self.get_node_pool,
                 default_retry=retries.Retry(
@@ -240,7 +243,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -256,7 +259,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -304,7 +307,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -317,7 +320,7 @@ class ClusterManagerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
                 ),
                 default_timeout=20.0,
@@ -524,6 +527,18 @@ class ClusterManagerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_json_web_keys(
+        self,
+    ) -> typing.Callable[
+        [cluster_service.GetJSONWebKeysRequest],
+        typing.Union[
+            cluster_service.GetJSONWebKeysResponse,
+            typing.Awaitable[cluster_service.GetJSONWebKeysResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def get_node_pool(
         self,
