@@ -16,8 +16,13 @@
 #
 
 from .cluster_service import (
+    LinuxNodeConfig,
+    NodeKubeletConfig,
     NodeConfig,
     ShieldedInstanceConfig,
+    SandboxConfig,
+    EphemeralStorageConfig,
+    ReservationAffinity,
     NodeTaint,
     MasterAuth,
     ClientCertificateConfig,
@@ -26,6 +31,11 @@ from .cluster_service import (
     HorizontalPodAutoscaling,
     KubernetesDashboard,
     NetworkPolicyConfig,
+    DnsCacheConfig,
+    KalmConfig,
+    ConfigConnectorConfig,
+    GcePersistentDiskCsiDriverConfig,
+    PrivateClusterMasterGlobalAccessConfig,
     PrivateClusterConfig,
     IstioConfig,
     CloudRunConfig,
@@ -36,6 +46,7 @@ from .cluster_service import (
     BinaryAuthorization,
     PodSecurityPolicyConfig,
     AuthenticatorGroupsConfig,
+    ClusterTelemetry,
     Cluster,
     ClusterUpdate,
     Operation,
@@ -98,16 +109,36 @@ from .cluster_service import (
     UsableSubnetworkSecondaryRange,
     UsableSubnetwork,
     VerticalPodAutoscaling,
+    DefaultSnatStatus,
     IntraNodeVisibilityConfig,
     MaxPodsConstraint,
+    WorkloadIdentityConfig,
     DatabaseEncryption,
     ResourceUsageExportConfig,
+    ShieldedNodes,
+    GetOpenIDConfigRequest,
+    GetOpenIDConfigResponse,
+    GetJSONWebKeysRequest,
+    Jwk,
+    GetJSONWebKeysResponse,
+    ReleaseChannel,
+    TpuConfig,
+    Master,
+    NotificationConfig,
+    ConfidentialNodes,
+    UpgradeEvent,
+    DatapathProvider,
+    UpgradeResourceType,
 )
 
-
 __all__ = (
+    "LinuxNodeConfig",
+    "NodeKubeletConfig",
     "NodeConfig",
     "ShieldedInstanceConfig",
+    "SandboxConfig",
+    "EphemeralStorageConfig",
+    "ReservationAffinity",
     "NodeTaint",
     "MasterAuth",
     "ClientCertificateConfig",
@@ -116,6 +147,11 @@ __all__ = (
     "HorizontalPodAutoscaling",
     "KubernetesDashboard",
     "NetworkPolicyConfig",
+    "DnsCacheConfig",
+    "KalmConfig",
+    "ConfigConnectorConfig",
+    "GcePersistentDiskCsiDriverConfig",
+    "PrivateClusterMasterGlobalAccessConfig",
     "PrivateClusterConfig",
     "IstioConfig",
     "CloudRunConfig",
@@ -126,6 +162,7 @@ __all__ = (
     "BinaryAuthorization",
     "PodSecurityPolicyConfig",
     "AuthenticatorGroupsConfig",
+    "ClusterTelemetry",
     "Cluster",
     "ClusterUpdate",
     "Operation",
@@ -188,8 +225,24 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "UsableSubnetwork",
     "VerticalPodAutoscaling",
+    "DefaultSnatStatus",
     "IntraNodeVisibilityConfig",
     "MaxPodsConstraint",
+    "WorkloadIdentityConfig",
     "DatabaseEncryption",
     "ResourceUsageExportConfig",
+    "ShieldedNodes",
+    "GetOpenIDConfigRequest",
+    "GetOpenIDConfigResponse",
+    "GetJSONWebKeysRequest",
+    "Jwk",
+    "GetJSONWebKeysResponse",
+    "ReleaseChannel",
+    "TpuConfig",
+    "Master",
+    "NotificationConfig",
+    "ConfidentialNodes",
+    "UpgradeEvent",
+    "DatapathProvider",
+    "UpgradeResourceType",
 )
